@@ -5,7 +5,7 @@
 #' @description
 #' Objects of class 'runjags' are produced by \code{\link{run.jags}}, \code{\link{results.jags}} and \code{\link{autorun.jags}}, and contain the MCMC chains as well as all information required to extend the simulation.  This function allows specific information to be extracted from these functions.  For other utility methods for the runjags class, see \code{\link{runjags-class}}.
 
-#' @details 
+#' @details
 #' The supported options for the 'what' argument are as follows:
 #' \itemize{
 #' \item{crosscorr}{ - the cross-correlation matrix}
@@ -26,7 +26,7 @@
 #' \item{full.deviance}{ - the sum of the model deviance at each iteration (for each chain)}
 #' \item{full.pd}{ - the sum of the estimated pD at each iteration}
 #' }
-#' Note that for the deviance/DIC related parameters, these will be extracted from the available information if possible, or otherwise re-sampled. 
+#' Note that for the deviance/DIC related parameters, these will be extracted from the available information if possible, or otherwise re-sampled.
 
 #' @keywords models
 
@@ -53,18 +53,18 @@ extract <- function(x, what, ...){
 #' @rdname extract.runjags
 #' @method extract runjags
 extract.runjags <- function(x, what, force.resample=FALSE, ...){
-	
+
 	if(missing(what) || length(what)!=1 || !is.character(what))
 		stop('A character vector of length 1 must be supplied for "what"')
-	
+
 	if(x$sample==0 && !what%in%c('model','data','end.state'))
 		stop('The runjags object has not yet been updated - use extend.jags to update the model')
-	
+
 	what <- tolower(what)
 	possibilities <- c('crosscorr', 'summary', 'model', 'data', 'end.state', 'samplers', 'stochastic', 'dic', 'ped', 'sum.deviance', 'sum.pd', 'sum.popt', 'mean.deviance', 'mean.pd', 'mean.popt', 'full.deviance', 'full.pd')
 	if(!what %in% possibilities)
 		stop(paste('Cannot extract "', what, '" - options are ', paste(possibilities,collapse=', '), sep=''))
-	
+
 	if(what=='crosscorr'){
 	  return(x$crosscorr)
 	}
@@ -95,7 +95,7 @@ extract.runjags <- function(x, what, force.resample=FALSE, ...){
 		return(toreturn)
   	}
   	# All the rest are DIC related:
-	
+
 	# These two are class defined by rjags, so need to do the resampling if necessary:
   	if(what=='dic'){
 	  return(dic.runjags(x, type='pD', force.resample=force.resample, ...))
@@ -103,95 +103,95 @@ extract.runjags <- function(x, what, force.resample=FALSE, ...){
 	if(what=='ped'){
 	  return(dic.runjags(x, type='popt', force.resample=force.resample, ...))
 	}
-	
+
 	# Some of the rest may be short-cutable from what we have saved:
 	if(what=='sum.deviance'){
-		if(!force.resample && !is.na(x$deviance.sum) && !is.na(x$deviance.sum['sum.mean.deviance']))
+		if(!force.resample && any(!is.na(x$deviance.sum)) && !is.na(x$deviance.sum['sum.mean.deviance']))
 			return(x$deviance.sum['sum.mean.deviance'])
-		
+
 		ds <- dic.runjags(x, type='pD', force.resample=force.resample, ...)
 		tab <- sum(as.matrix(ds$deviance))
 		names(tab) <- 'sum.mean.deviance'
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='sum.pd'){
-		if(!force.resample && !is.na(x$deviance.sum) && !is.na(x$deviance.sum['sum.mean.pD']))
+		if(!force.resample && any(!is.na(x$deviance.sum)) && !is.na(x$deviance.sum['sum.mean.pD']))
 			return(x$deviance.sum['sum.mean.pD'])
-		
+
 		ds <- dic.runjags(x, type='pD', force.resample=force.resample, ...)
 		tab <- sum(as.matrix(ds$penalty))
 		names(tab) <- 'sum.mean.pD'
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='sum.popt'){
-		if(!force.resample && !is.na(x$deviance.sum) && !is.na(x$deviance.sum['sum.mean.pOpt']))
+		if(!force.resample && any(!is.na(x$deviance.sum)) && !is.na(x$deviance.sum['sum.mean.pOpt']))
 			return(x$deviance.sum['sum.mean.pOpt'])
-		
+
 		ds <- dic.runjags(x, type='pOpt', force.resample=force.resample, ...)
 		tab <- sum(as.matrix(ds$penalty))
 		names(tab) <- 'sum.mean.pOpt'
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='mean.deviance'){
-		if(!force.resample && !is.na(x$deviance.table) && all(!is.na(x$deviance.table['mean.deviance'])))
+		if(!force.resample && any(!is.na(x$deviance.table)) && all(!is.na(x$deviance.table['mean.deviance'])))
 			return(x$deviance.table['mean.deviance'])
-		
+
 		ds <- dic.runjags(x, type='pD', force.resample=force.resample, ...)
 		tab <- t(as.matrix(ds$deviance))
 		dimnames(tab) <- list('mean.deviance', dimnames(tab)[[2]])
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='mean.pd'){
-		if(!force.resample && !is.na(x$deviance.table) && all(!is.na(x$deviance.table['mean.pD'])))
+		if(!force.resample && any(!is.na(x$deviance.table)) && all(!is.na(x$deviance.table['mean.pD'])))
 			return(x$deviance.table['mean.pD'])
-		
+
 		ds <- dic.runjags(x, type='pD', force.resample=force.resample, ...)
 		tab <- t(as.matrix(ds$penalty))
 		dimnames(tab) <- list('mean.pD', dimnames(tab)[[2]])
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='mean.popt'){
-		if(!force.resample && !is.na(x$deviance.table) && all(!is.na(x$deviance.table['mean.pOpt'])))
+		if(!force.resample && any(!is.na(x$deviance.table)) && all(!is.na(x$deviance.table['mean.pOpt'])))
 			return(x$deviance.table['mean.pOpt'])
-		
+
 		ds <- dic.runjags(x, type='pOpt', force.resample=force.resample, ...)
 		tab <- t(as.matrix(ds$penalty))
 		dimnames(tab) <- list('mean.pOpt', dimnames(tab)[[2]])
-		return(tab)		
+		return(tab)
 	}
-	
+
 	if(what=='full.deviance'){
 		if(any(varnames(x$mcmc)=='deviance'))
       		return(as.mcmc.list(x, vars='deviance'))
-		
+
 		stop('The full deviance can only be extracted from runjags objects originally run (or extended) with a deviance monitor')
 	}
-	
+
 	if(what=='full.pd'){
 		if(!identical(x$pd, NA))
 			return(x$pd)
-    
+
 		stop('The full pD can only be extracted from runjags objects originally run (or extended) using the simple or interruptible methods')
 	}
-	
+
 }
 
 dic.runjags <- function(x, type='pD', force.resample=FALSE, adapt=1000, n.iter=x$sample, quiet=FALSE, ...){
 
 	runjags.object <- checkvalidrunjagsobject(x)
-	
+
 	if(!loadandcheckrjags(FALSE))
 		stop('Returning DIC objects requires the rjags package')
-	
+
 	type <- tolower(type)
 	if(!type%in%c('pd','popt')) stop('The type argument must be either pD or popt')
 	if(type=='pd') type <- 'pD'
-	
+
 	# If dic samples taken already, return what dic.samples would, otherwise call extend.jags
 	if(force.resample || identical(runjags.object$deviance.table, NA) || n.iter!=x$sample){
 		redo <- TRUE
@@ -203,15 +203,15 @@ dic.runjags <- function(x, type='pD', force.resample=FALSE, adapt=1000, n.iter=x
 			redo <- TRUE
 		if(nrow(runjags.object$deviance.table)==1 && dimnames(runjags.object$deviance.table)[[1]]=='mean')
 			redo <- TRUE
-	
+
 	}
 
   if(redo){
 	newobj <- as.jags(runjags.object, adapt=adapt, quiet=quiet)
-	
+
 	if(!quiet)
 		swcat('Obtaining DIC samples from ', n.iter, ' iterations...\n')
-	
+
 	if(quiet){
 		dics <- rjags::dic.samples(newobj, type=type, n.iter=n.iter, progress.bar='none', ...)
 	}else{
@@ -220,12 +220,12 @@ dic.runjags <- function(x, type='pD', force.resample=FALSE, adapt=1000, n.iter=x
 
 	if(runjags.getOption('repeatable.methods'))
 		warning('The rjags object has been updated, so subsequent samples taken with extend.jags(..., method="rjags") will not match those taken using other methods!')
-			
+
 	}else{
 		pencol <- if(type=='pD') 2 else 3
 		dics <- list(deviance=runjags.object$deviance.table[,1], penalty=runjags.object$deviance.table[,pencol], type=type)
 		class(dics) <- 'dic'
 	}
-	
+
 	return(dics)
 }
